    .. _upnp_services_clients_rendering_control_client:

coherence.upnp.services.clients.rendering\_control\_client (module)
-------------------------------------------------------------------

.. automodule:: coherence.upnp.services.clients.rendering_control_client
